Learn R Programming

BoltzMM (version 0.1.5)

log_pl_calc: Compute the log pseudolikelihood

Description

Compute the log pseudolikelihood C++ version

Usage

log_pl_calc(data, L)

Value

The the log pseudolikelihood of [].

Arguments

data

An N by n matrix, where each of the N rows contains a length n string of spin variables (i.e. each element is -1 or 1).

L

A list storing the parameter vectors a and b, and matrices A, B and C

Author

Andrew T. Jones and Hien D. Nguyen