powered by
Compute the log pseudolikelihood C++ version
log_pl_calc(data, L)
The the log pseudolikelihood of [].
An N by n matrix, where each of the N rows contains a length n string of spin variables (i.e. each element is -1 or 1).
A list storing the parameter vectors a and b, and matrices A, B and C
Andrew T. Jones and Hien D. Nguyen